@@ -257,6 +257,10 @@ impl World {
         let archetype = &mut self.archetypes.archetypes[archetype_id as usize];
         for (&handle, index) in handles.iter().zip(base as usize..) {
             archetype.set_entity_id(index, handle.id());
+            self.entities.meta[handle.id() as usize].location = Location {
+                archetype: archetype_id,
+                index: index as u32,
+            };
         }
     }
 
@@ -1052,7 +1056,7 @@ impl Iterator for SpawnColumnBatchIter<'_> {
     type Item = Entity;
 
     fn next(&mut self) -> Option<Entity> {
-        let id = self.id_alloc.next(&self.entities)?;
+        let id = self.id_alloc.next(self.entities)?;
         Some(unsafe { self.entities.resolve_unknown_gen(id) })
     }
 
@@ -1063,7 +1067,7 @@ impl Iterator for SpawnColumnBatchIter<'_> {
 
 impl ExactSizeIterator for SpawnColumnBatchIter<'_> {
     fn len(&self) -> usize {
-        self.id_alloc.len(&self.entities)
+        self.id_alloc.len(self.entities)
     }
 }
 
